@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: ddvcard.h 233 2006-09-11 15:18:03Z martin $
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -14,9 +11,9 @@
 #ifndef CHIPCARD_CARD_EGKCARD_H
 #define CHIPCARD_CARD_EGKCARD_H
 
-#include <chipcard/client/card.h>
-#include <chipcard/client/cards/hipersonaldata.h>
-#include <chipcard/client/cards/hiinsurancedata.h>
+#include <chipcard/card.h>
+#include <chipcard/cards/hipersonaldata.h>
+#include <chipcard/cards/hiinsurancedata.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -77,7 +74,7 @@ CHIPCARD_API LC_CLIENT_RESULT LC_EgkCard_SecureVerifyPin(LC_CARD *card);
 /*@}*/
 
 
-/** @name Reading Card Data
+/** @name Reading And Parsing Card Data
  *
  */
 /*@{*/
@@ -93,6 +90,10 @@ CHIPCARD_API
 LC_CLIENT_RESULT LC_EgkCard_ReadInsuranceData(LC_CARD *card,
 					      LC_HI_INSURANCE_DATA **pData);
 
+CHIPCARD_API 
+LC_CLIENT_RESULT LC_EgkCard_ParseInsuranceData(GWEN_XMLNODE *root,
+					       LC_HI_INSURANCE_DATA **pData);
+
 /*@}*/
 
 
