@@ -12,17 +12,21 @@
 #define CHIPCARD_CARD_ZKACARD_P_H
 
 #include "zkacard.h"
+#include "pininfo_l.h"
 
 #include <chipcard/card_imp.h>
 
 
+
 typedef struct LC_ZKACARD LC_ZKACARD;
 struct LC_ZKACARD {
   LC_CARD_OPEN_FN openFn;
   LC_CARD_CLOSE_FN closeFn;
 
-  GWEN_BUFFER *bin_ef_gd_0;
   GWEN_BUFFER *bin_ef_id;
+  GWEN_DB_NODE *db_ef_id;
+
+  GWEN_BUFFER *bin_ef_gd_0;
   GWEN_BUFFER *bin_ef_ssd;
 
   int len_modus_sk_ch_ds;
@@ -30,14 +34,24 @@ struct LC_ZKACARD {
   int len_modus_sk_ch_ke;
   int min_len_csa_password;
 
+  LC_PININFO_LIST *pinInfoList;
 };
 
 
-void GWENHYWFAR_CB LC_ZkaCard_freeData(void *bp, void *p);
-LC_CLIENT_RESULT CHIPCARD_CB LC_ZkaCard_Open(LC_CARD *card);
-LC_CLIENT_RESULT CHIPCARD_CB LC_ZkaCard_Close(LC_CARD *card);
+static void GWENHYWFAR_CB LC_ZkaCard_freeData(void *bp, void *p);
+static LC_CLIENT_RESULT CHIPCARD_CB LC_ZkaCard_Open(LC_CARD *card);
+static LC_CLIENT_RESULT CHIPCARD_CB LC_ZkaCard_Close(LC_CARD *card);
+static LC_CLIENT_RESULT CHIPCARD_CB LC_ZkaCard_GetPinStatus(LC_CARD *card,
+                                                            unsigned int pid,
+                                                            int *maxErrors,
+                                                            int *currentErrors);
 
 
+static LC_CLIENT_RESULT LC_ZkaCard__PrepareSign(LC_CARD *card, int globalKey, int keyId, int keyVersion);
+static int LC_ZkaCard__ParsePseudoOids(const uint8_t *p, uint32_t bs, GWEN_BUFFER *mbuf);
+
+
+static int LC_ZkaCard__ReadPwdd(LC_CARD *card);
 
 
 #endif
