@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -16,8 +13,8 @@
 
 
 #include <chipcard/chipcard.h>
-#include <chipcard/client/client.h>
-#include <chipcard/client/cards/geldkarte.h>
+#include <chipcard/client.h>
+#include <chipcard/cards/geldkarte.h>
 
 #include <gwenhywfar/logger.h>
 
