@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -20,7 +17,7 @@
  * it ;-)
  */
 #include <chipcard/chipcard.h>
-#include <chipcard/client/client.h>
+#include <chipcard/client.h>
 
 
 /**
@@ -43,7 +40,7 @@ int main(int argc, char **argv) {
 
   LC_Card_Open(card);
 
-  LC_Card_Dump(card, stderr, 0);
+  LC_Card_Dump(card, 0);
 
   LC_Card_Close(card);
   LC_Client_ReleaseCard(cl, card);
